PDBModel
===============

.. currentmodule:: biskit

.. autoclass:: PDBModel
   :members:
   :show-inheritance:
   :special-members: __init__

   

   
   .. rubric:: Methods Overview

   .. autosummary::
      :nosignatures:
   
   
      ~PDBModel.__init__
      ~PDBModel.addChainFromSegid
      ~PDBModel.addChainId
      ~PDBModel.argsort
      ~PDBModel.atom2chainIndices
      ~PDBModel.atom2chainMask
      ~PDBModel.atom2resIndices
      ~PDBModel.atom2resMask
      ~PDBModel.atom2resProfile
      ~PDBModel.atomNames
      ~PDBModel.atomRange
      ~PDBModel.atomkey
      ~PDBModel.biomodel
      ~PDBModel.center
      ~PDBModel.centerOfMass
      ~PDBModel.centered
      ~PDBModel.chain2atomIndices
      ~PDBModel.chain2atomMask
      ~PDBModel.chainBreaks
      ~PDBModel.chainEndIndex
      ~PDBModel.chainIndex
      ~PDBModel.chainMap
      ~PDBModel.clone
      ~PDBModel.compareAtoms
      ~PDBModel.compareChains
      ~PDBModel.compress
      ~PDBModel.concat
      ~PDBModel.disconnect
      ~PDBModel.equals
      ~PDBModel.extendIndex
      ~PDBModel.extendMask
      ~PDBModel.filter
      ~PDBModel.filterIndex
      ~PDBModel.fit
      ~PDBModel.getAtoms
      ~PDBModel.getPdbCode
      ~PDBModel.getXyz
      ~PDBModel.index2map
      ~PDBModel.indices
      ~PDBModel.indicesFrom
      ~PDBModel.keep
      ~PDBModel.lenAtoms
      ~PDBModel.lenBiounits
      ~PDBModel.lenChains
      ~PDBModel.lenResidues
      ~PDBModel.magicFit
      ~PDBModel.map2index
      ~PDBModel.mask
      ~PDBModel.maskBB
      ~PDBModel.maskCA
      ~PDBModel.maskCB
      ~PDBModel.maskDNA
      ~PDBModel.maskF
      ~PDBModel.maskFrom
      ~PDBModel.maskH
      ~PDBModel.maskH2O
      ~PDBModel.maskHeavy
      ~PDBModel.maskHetatm
      ~PDBModel.maskNA
      ~PDBModel.maskProtein
      ~PDBModel.maskRNA
      ~PDBModel.maskSolvent
      ~PDBModel.mass
      ~PDBModel.masses
      ~PDBModel.mergeChains
      ~PDBModel.mergeResidues
      ~PDBModel.plot
      ~PDBModel.profile
      ~PDBModel.profile2atomMask
      ~PDBModel.profile2mask
      ~PDBModel.profile2resList
      ~PDBModel.profileChangedFromDisc
      ~PDBModel.profileInfo
      ~PDBModel.remove
      ~PDBModel.removeProfile
      ~PDBModel.removeRes
      ~PDBModel.renameAmberRes
      ~PDBModel.renumberResidues
      ~PDBModel.report
      ~PDBModel.reportAtoms
      ~PDBModel.res2atomIndices
      ~PDBModel.res2atomMask
      ~PDBModel.res2atomProfile
      ~PDBModel.resEndIndex
      ~PDBModel.resIndex
      ~PDBModel.resList
      ~PDBModel.resMap
      ~PDBModel.resMapOriginal
      ~PDBModel.resModels
      ~PDBModel.residusMaximus
      ~PDBModel.rms
      ~PDBModel.saveAs
      ~PDBModel.sequence
      ~PDBModel.setPdbCode
      ~PDBModel.setSource
      ~PDBModel.setXyz
      ~PDBModel.slim
      ~PDBModel.sort
      ~PDBModel.sourceFile
      ~PDBModel.structureFit
      ~PDBModel.take
      ~PDBModel.takeChains
      ~PDBModel.takeResidues
      ~PDBModel.transform
      ~PDBModel.transformation
      ~PDBModel.unequalAtoms
      ~PDBModel.unsort
      ~PDBModel.update
      ~PDBModel.validSource
      ~PDBModel.version
      ~PDBModel.writePdb
      ~PDBModel.xplor2amber
      ~PDBModel.xyzChangedFromDisc
      ~PDBModel.xyzIsChanged
   
   

   
   
   .. rubric:: Attributes Overview

   .. autosummary::
   
      ~PDBModel.PDB_KEYS
   
   

   
   
   .. raw:: html
      
      <hr>
      <h2>PDBModel Method & Attribute Details</h2>

   
   